==> haskell-hackage-security-0.6.2.6-84-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hackage-security.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hackage-security
version:              0.6.2.6
visibility:           public
id:                   hackage-security-0.6.2.6-CV31rryoOyplgfSsO7TMC
key:                  hackage-security-0.6.2.6-CV31rryoOyplgfSsO7TMC
license:              BSD-3-Clause
copyright:            Copyright 2015-2022 Well-Typed LLP
maintainer:           cabal-devel@haskell.org
author:               Edsko de Vries
homepage:             https://github.com/haskell/hackage-security
synopsis:             Hackage security library
description:
    The hackage security library provides both server and
    client utilities for securing the Hackage package server
    (<https://hackage.haskell.org/>).  It is based on The Update
    Framework (<https://theupdateframework.com/>), a set of
    recommendations developed by security researchers at
    various universities in the US as well as developers on the
    Tor project (<https://www.torproject.org/>).

    The current implementation supports only index signing,
    thereby enabling untrusted mirrors. It does not yet provide
    facilities for author package signing.

    The library has two main entry points:
    "Hackage.Security.Client" is the main entry point for
    clients (the typical example being @cabal@), and
    "Hackage.Security.Server" is the main entry point for
    servers (the typical example being @hackage-server@).

category:             Distribution
abi:                  3715556c7483cbcbb155cf89bfeb81f1
exposed:              True
exposed-modules:
    Hackage.Security.Client Hackage.Security.Client.Formats
    Hackage.Security.Client.Repository
    Hackage.Security.Client.Repository.Cache
    Hackage.Security.Client.Repository.HttpLib
    Hackage.Security.Client.Repository.Local
    Hackage.Security.Client.Repository.Remote
    Hackage.Security.Client.Verify Hackage.Security.JSON
    Hackage.Security.Key.Env Hackage.Security.Server
    Hackage.Security.TUF.FileMap Hackage.Security.Trusted
    Hackage.Security.Util.Checked Hackage.Security.Util.Path
    Hackage.Security.Util.Pretty Hackage.Security.Util.Some
    Text.JSON.Canonical

hidden-modules:
    Hackage.Security.Key Hackage.Security.Trusted.TCB
    Hackage.Security.TUF Hackage.Security.TUF.Common
    Hackage.Security.TUF.FileInfo Hackage.Security.TUF.Header
    Hackage.Security.TUF.Layout.Cache Hackage.Security.TUF.Layout.Index
    Hackage.Security.TUF.Layout.Repo Hackage.Security.TUF.Mirrors
    Hackage.Security.TUF.Paths Hackage.Security.TUF.Patterns
    Hackage.Security.TUF.Root Hackage.Security.TUF.Signed
    Hackage.Security.TUF.Snapshot Hackage.Security.TUF.Targets
    Hackage.Security.TUF.Timestamp Hackage.Security.Util.Base64
    Hackage.Security.Util.Exit Hackage.Security.Util.IO
    Hackage.Security.Util.JSON Hackage.Security.Util.Lens
    Hackage.Security.Util.Stack Hackage.Security.Util.TypedEmbedded

import-dirs:          /usr/lib/ghc-9.4.8/site-local/hackage-security-0.6.2.6
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hackage-security-0.6.2.6
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hackage-security-0.6.2.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hackage-security
hs-libraries:         HShackage-security-0.6.2.6-CV31rryoOyplgfSsO7TMC
depends:
    Cabal-syntax-3.8.1.0 base-4.17.2.1
    base16-bytestring-1.0.2.0-2U8KlRNggLqLs1cZzvTsOg
    base64-bytestring-1.2.1.0-B7TpHxQlQ7x5xHtuAREw0z
    bytestring-0.11.5.3 containers-0.6.7
    cryptohash-sha256-0.11.102.1-51bloADwKm07Nm7zxUYeej
    directory-1.3.7.1 ed25519-0.0.5.0-8644XuUf7h2DKMAvPBqI1l
    filepath-1.4.2.2 ghc-prim-0.9.1
    lukko-0.1.1.3-3hHrTaVIcHBF0cwjJPvzrw mtl-2.2.2
    network-3.1.4.0-Clrm8B2IBAjIFHTKmEcInu
    network-uri-2.6.4.2-KyuZLjrVkMLH56LkxlYTeb parsec-3.1.16.1
    pretty-1.1.3.6 tar-0.5.1.1-2pBm5trXBeZI0XPt4VopgC
    template-haskell-2.19.0.0 time-1.12.2 transformers-0.5.6.2
    zlib-0.7.0.0-HNsXCdLk9sG62mRngTZgti

haddock-interfaces:
    /usr/share/doc/haskell-hackage-security/html/hackage-security.haddock

haddock-html:         /usr/share/doc/haskell-hackage-security/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hackage-security-0.6.2.6-85-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hackage-security.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hackage-security
version:              0.6.2.6
visibility:           public
id:                   hackage-security-0.6.2.6-AGX2gNmeW9C2MOx2eczi13
key:                  hackage-security-0.6.2.6-AGX2gNmeW9C2MOx2eczi13
license:              BSD-3-Clause
copyright:            Copyright 2015-2022 Well-Typed LLP
maintainer:           cabal-devel@haskell.org
author:               Edsko de Vries
homepage:             https://github.com/haskell/hackage-security
synopsis:             Hackage security library
description:
    The hackage security library provides both server and
    client utilities for securing the Hackage package server
    (<https://hackage.haskell.org/>).  It is based on The Update
    Framework (<https://theupdateframework.com/>), a set of
    recommendations developed by security researchers at
    various universities in the US as well as developers on the
    Tor project (<https://www.torproject.org/>).

    The current implementation supports only index signing,
    thereby enabling untrusted mirrors. It does not yet provide
    facilities for author package signing.

    The library has two main entry points:
    "Hackage.Security.Client" is the main entry point for
    clients (the typical example being @cabal@), and
    "Hackage.Security.Server" is the main entry point for
    servers (the typical example being @hackage-server@).

category:             Distribution
abi:                  b365503a7a7b2beaa934f4b5bbe2b44e
exposed:              True
exposed-modules:
    Hackage.Security.Client Hackage.Security.Client.Formats
    Hackage.Security.Client.Repository
    Hackage.Security.Client.Repository.Cache
    Hackage.Security.Client.Repository.HttpLib
    Hackage.Security.Client.Repository.Local
    Hackage.Security.Client.Repository.Remote
    Hackage.Security.Client.Verify Hackage.Security.JSON
    Hackage.Security.Key.Env Hackage.Security.Server
    Hackage.Security.TUF.FileMap Hackage.Security.Trusted
    Hackage.Security.Util.Checked Hackage.Security.Util.Path
    Hackage.Security.Util.Pretty Hackage.Security.Util.Some
    Text.JSON.Canonical

hidden-modules:
    Hackage.Security.Key Hackage.Security.Trusted.TCB
    Hackage.Security.TUF Hackage.Security.TUF.Common
    Hackage.Security.TUF.FileInfo Hackage.Security.TUF.Header
    Hackage.Security.TUF.Layout.Cache Hackage.Security.TUF.Layout.Index
    Hackage.Security.TUF.Layout.Repo Hackage.Security.TUF.Mirrors
    Hackage.Security.TUF.Paths Hackage.Security.TUF.Patterns
    Hackage.Security.TUF.Root Hackage.Security.TUF.Signed
    Hackage.Security.TUF.Snapshot Hackage.Security.TUF.Targets
    Hackage.Security.TUF.Timestamp Hackage.Security.Util.Base64
    Hackage.Security.Util.Exit Hackage.Security.Util.IO
    Hackage.Security.Util.JSON Hackage.Security.Util.Lens
    Hackage.Security.Util.Stack Hackage.Security.Util.TypedEmbedded

import-dirs:          /usr/lib/ghc-9.4.8/site-local/hackage-security-0.6.2.6
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hackage-security-0.6.2.6
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hackage-security-0.6.2.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hackage-security
hs-libraries:         HShackage-security-0.6.2.6-AGX2gNmeW9C2MOx2eczi13
depends:
    Cabal-syntax-3.8.1.0 base-4.17.2.1
    base16-bytestring-1.0.2.0-xTrtAtNLYsAcMjivoMGOH
    base64-bytestring-1.2.1.0-Jr4dnoqop9Z6dS9yQYn7ws
    bytestring-0.11.5.3 containers-0.6.7
    cryptohash-sha256-0.11.102.1-LUC1LO7Cluu6LmiOUVfw09
    directory-1.3.7.1 ed25519-0.0.5.0-8644XuUf7h2DKMAvPBqI1l
    filepath-1.4.2.2 ghc-prim-0.9.1
    lukko-0.1.1.3-FjWxCOKJvCkI7tipjbBa5k mtl-2.2.2
    network-3.1.4.0-ASj1hBk5tU17JSnFMFmeWy
    network-uri-2.6.4.2-4a4fvaL8hlS8iUTVwHnYtf parsec-3.1.16.1
    pretty-1.1.3.6 tar-0.5.1.1-IMIbdPp4JXc9EsuXTmUVnu
    template-haskell-2.19.0.0 time-1.12.2 transformers-0.5.6.2
    zlib-0.7.0.0-FA6aBLxMBUm8GSDapkxrxA

haddock-interfaces:
    /usr/share/doc/haskell-hackage-security/html/hackage-security.haddock

haddock-html:         /usr/share/doc/haskell-hackage-security/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
